pub enum Timestamp {
Duration(Duration),
Fraction(f32),
}Variants
Duration(Duration)
The timestamp, measured as the duration elapsed since the track onset until the exposure started.
Fraction(f32)
In cases where no time is available, the fraction done.
Implementations