FrameData

Struct FrameData 

pub struct FrameData { /* private fields */ }
A single frame of data, including image and timestamp fields.

Implementations

Source

impl FrameData

pub fn timestamp(&self) -> Timestamp

Get the timestamp, measured as the duration elapsed since the track onset until the exposure started.

This is often called “PTS” (presentation time stamp).

pub fn image(&self) -> &ImageData

Get the image data

pub fn into_image(self) -> ImageData

Get the image data

pub fn num_bytes(&self) -> usize

Get the number of the bytes used in the source.

pub fn idx(&self) -> usize

Get the number of the frame in the source, in decode order.

Starts with 0. See the field docs on FrameData for the decode- vs presentation-order distinction.

pub fn poc(&self) -> Option<i64>

Get the frame’s picture order count (POC), when known.

See the FrameData::poc field docs. None for non-H.264 sources or when POC could not be reconstructed.

pub fn decoded<'a>(&'a self) -> Option<DynamicFrame<'a>>

pub fn take_decoded(self) -> Option<DynamicFrameOwned>